## OpenDataDiscovery CLI
[![PyPI version](https://badge.fury.io/py/odd-cli.svg)](https://badge.fury.io/py/odd-cli)

Command line tool for working with OpenDataDiscovery. 
It makes it easy to create token though console and ingest local dataset's metadata to OpenDataDiscovery platform.


#### Available commands
```text
╭─ Options ────────────────────────────────────────────────────────────────────────────────────────────────────────────╮
│ --install-completion          Install completion for the current shell.                                              │
│ --show-completion             Show completion for the current shell, to copy it or customize the installation        │
╰──────────────────────────────────────────────────────────────────────────────────────────────────────────────────────╯
╭─ Commands ─────────────────────────────────────────────────────────────────────────────────╮
│ collect                       Collect and ingest metadata for local files from folder      │
│ tokens                        Manipulate OpenDataDiscovery platform's tokens               │
╰────────────────────────────────────────────────────────────────────────────────────────────╯
```